
# q-expansion of newform 8034.2.a.v, downloaded from the LMFDB on 07 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 8034
weight = 2
poly_data = [576, 4024, -10494, -2065, 8532, -736, -1928, 300, 168, -31, -5, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[159253845372, -278709400064, -292454456923, 192625837968, 75666608448, -29633121208, -7557802336, 1471530490, 354406289, -17965281, -7214441], 24169157748], [[3291397224, 68038889518, -58601234445, -42269912108, 10889091824, 11904407208, -1247220084, -1300710052, 154221401, 45806123, -6954475], 16112771832], [[68016964824, 34242147922, -160415090299, -26795724084, 53455821804, -2903894740, -4060162144, 1153915696, -96960025, -58843755, 12175783], 24169157748], [[16835685894, 42230737499, 83266816921, -39173547342, -51187504290, 11048729236, 8087991802, -1187809591, -439905770, 42249738, 6501563], 12084578874], [[-67756366224, 30146158625, 95351395795, -39173547342, -51187504290, 11048729236, 8087991802, -1187809591, -439905770, 42249738, 6501563], 12084578874], [[-332744495184, -33353267558, -197764359613, 3251983908, 196673190432, 10235837864, -36952460260, -1691813840, 2616704621, 67818039, -64472003], 48338315496], [[-20159257776, 142993848946, 40432304461, -127738310148, 1318194840, 30309554056, -2917748212, -2717567812, 372751607, 82204613, -13289341], 5370923944], [[-33312963024, -504759302554, 307612462405, 597489887604, -239310756048, -155126675336, 51523740940, 14601473048, -4328210285, -456748671, 125904587], 48338315496], [[9170866704, -88710185906, 28287160275, 64779403690, -21039436504, -14049457206, 4492255116, 1228551980, -379154155, -37445815, 11080037], 4028192958]]

hecke_ring_character_values = None
aps_data = [[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [-1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0], [2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0], [3, 0, 1, -1, -1, 0, 0, 0, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0], [2, 0, 0, -1, 1, 0, 0, 0, 0, 1, 0], [-1, 0, 0, 0, 0, -1, 0, -1, 0, 0, 0], [-1, 0, 0, 0, 0, 1, -1, 0, -1, 0, -1], [1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0], [2, -2, 0, 0, -1, 0, 0, 0, -1, -1, 1], [-3, 0, 1, -1, -1, 1, 0, 1, 1, 1, -1], [0, 0, -1, 1, -1, 0, 0, -1, -1, 0, 2], [0, -1, 0, 1, 1, 1, -1, 0, 0, 1, -1], [3, 0, 0, 1, 1, 2, -1, 1, 0, 2, 0], [-1, 0, 1, -1, 0, 1, -1, 0, 1, 2, -1], [5, -1, 0, 0, -1, 1, -1, 0, 0, 0, 0], [3, -2, 1, -2, 0, 0, 0, 1, 1, 0, -1], [2, 0, 0, -1, 0, -2, 0, -1, -1, 0, 0], [-2, -1, 0, -2, 1, -1, 1, 0, 0, -1, 0], [2, -1, 0, -1, 0, -1, 2, 0, 0, 0, 1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 0, 1, -2, -1, 0, 0, -1, -2, 1], [-1, 1, 1, 0, 0, 0, 1, -1, -1, -1, 1], [4, -2, 0, 0, 0, -1, 0, 1, 0, -1, -1], [3, -2, 1, -2, 0, 0, 1, 0, 0, -1, 0], [4, 0, 1, 0, 0, -1, 0, -1, 0, 1, -1], [4, 0, 1, 1, -2, 0, -1, 0, 0, 0, -1], [4, 0, 0, -1, 0, 0, 0, 1, 0, 3, -2], [3, -3, 1, -1, 0, 2, -1, 2, 1, 0, -1], [-1, 3, 0, 0, 1, 2, -1, 1, -1, 3, 1], [4, -3, -1, -1, 1, 0, -1, -1, 0, 0, 0], [4, 1, -1, 0, 0, 0, 1, 0, 1, 1, -1], [4, 0, 0, 0, -1, 3, -1, 0, -1, 2, -1], [1, 1, -1, 2, 0, -2, 1, -1, 2, -2, 1], [8, -1, 0, 0, -1, 2, -1, 0, -1, 0, 0], [-4, 0, -1, 2, 1, -2, 0, -2, 0, -1, 1], [0, -1, 0, -1, 0, 1, 1, 0, -2, -1, 1], [-7, 1, 0, 2, -1, -1, 1, 0, 1, 2, 0], [10, -2, -1, -1, 0, 2, 0, 3, 0, 2, 1], [-1, -2, -1, -1, -1, 1, 2, 1, -1, -2, 2], [-2, 3, -1, 3, 1, -2, 2, -2, 1, -1, 1], [-1, 3, 0, 1, 0, 0, 0, 1, 1, 4, 1], [-4, -2, 0, -1, 1, 0, 0, -1, 0, -3, 1], [-4, 2, 0, -2, -1, 0, 1, 0, 1, -1, 0], [4, -2, -1, -1, 1, 0, 1, 0, 0, 0, -1], [-3, -4, 1, 0, -1, -1, -1, -1, 0, -4, 1], [1, -2, -1, 1, 0, -1, 1, 0, 0, -2, 1], [-3, -1, -2, 0, -2, -2, 0, 0, 0, -3, 0], [2, 0, 0, 1, -2, 0, -1, -2, -2, 0, 0], [3, 1, 1, 0, 2, 2, -3, 1, 1, 2, -2], [0, 1, 1, 0, 1, 0, 1, 1, 2, 2, -2], [-1, 3, 0, 0, 2, 2, 1, 2, 1, 4, 0], [-3, -2, 0, 2, 0, -2, 0, -1, 0, -2, -1], [0, -1, -3, 2, 2, -1, 0, -1, 0, -1, 2], [4, -2, 1, -2, 2, 1, -1, 2, 2, 5, -3], [4, 3, -3, 0, -1, 1, 1, 1, -1, 0, 2], [-5, 2, -1, 2, 2, 0, -2, -2, -2, 0, 0], [-7, 2, 2, -1, 3, 0, -1, -2, 1, 3, -2], [-2, -1, -1, -1, -2, 1, 0, 2, -2, -3, 0], [-3, 1, 0, 4, 1, 1, 0, -1, 0, -1, -1], [3, -1, 1, -1, 1, -3, 0, -2, 0, -3, -2], [4, 2, -1, 0, 1, 2, 1, 0, -4, 0, 1], [0, 0, -2, 3, 2, -1, 1, 0, 2, 4, 1], [-4, 1, -1, 1, -1, 1, -1, 0, 0, 4, 2], [3, -3, -2, -1, -1, 0, 1, -1, -3, -5, 1], [2, 0, 2, -1, 1, -3, 1, 1, 4, 0, -1], [0, -2, 2, -1, 1, -1, 1, 0, 1, 0, -1], [0, 3, 0, -1, 0, 1, -1, -2, 0, 2, 0], [4, 0, -1, 2, -1, -1, -1, 1, 0, 1, 4], [-14, -1, -1, 1, 2, 2, -1, 0, 0, -2, 0], [1, 2, 0, 0, 1, -1, -1, 2, 0, 3, 0], [3, 4, 4, 1, 0, 2, 0, 2, 1, 4, 0], [-8, 0, 1, 4, 1, -1, -1, -1, 0, 0, 1], [2, 2, 1, 0, -1, -2, 4, 2, 3, 0, 3], [-5, -1, 2, 1, -3, -2, 1, -1, 0, -5, 0], [3, -2, -1, 1, 0, 1, 0, 2, 2, 3, -2], [1, -2, 4, -6, 1, 0, 1, 1, -1, -3, -2], [-2, 2, 3, 0, -2, 3, -3, -1, -1, -2, -4], [2, 1, 0, 3, 0, 0, 1, 0, -2, 1, 0], [13, -3, -2, 0, 1, 2, 1, 2, 1, 2, 2], [-2, 0, 0, -1, -1, -3, 1, -2, -2, -3, 3], [3, 2, 0, 1, 0, -2, -2, 0, 0, 2, 0], [-1, 3, 0, 0, -2, 0, -1, 0, 2, 2, -1], [-3, 6, 1, 2, -1, 1, 1, -2, -3, -2, 1], [10, 1, 0, 2, -2, 2, -1, 1, -1, 1, -1], [-1, 2, 1, 1, -2, 1, 0, 1, 0, -1, -1], [-5, 2, 1, -1, 1, -1, -1, 0, 0, -1, -1], [5, 0, -2, -2, 3, 1, 0, 0, -2, 2, 2], [-1, -3, 2, 1, -2, 0, 1, -3, 0, -4, 0], [7, 3, -1, -2, 1, -1, 0, 3, 1, 2, -1], [4, 7, -1, 4, 0, 3, -1, -2, -1, 4, 0], [3, -6, -1, -1, 1, 2, 1, 0, -2, -1, 0], [3, 4, -1, 1, -1, 2, 1, 3, -2, 1, 1], [-1, -2, -2, 1, -1, 0, -2, 1, 0, -2, 4], [1, 2, -1, 0, 5, 3, 1, 3, 3, 7, -2], [2, 4, 3, 2, 2, -1, 0, 0, 2, 6, 1], [7, -3, -4, 2, -1, 2, 0, 1, 0, 2, 3], [3, -1, -2, 2, 4, 1, -3, 1, 1, 3, 1], [-5, -2, 1, -4, -2, -1, -1, 2, -1, 0, -1], [-8, 3, 0, 4, 0, 2, -2, -2, -2, -1, 3], [-13, 2, 0, 3, 1, -4, 1, -4, 2, -3, -1], [-3, 0, 2, -1, 3, 1, 0, 2, 3, -3, -2], [4, 1, 0, -1, 1, -3, -1, -1, -2, 0, 0], [-2, 6, -1, 2, 2, 1, 0, 0, 2, 4, -1], [-1, -1, 2, -3, -2, 0, 1, 0, 2, -3, 0], [-7, -1, -4, 2, 0, -1, 1, 1, -1, -6, 1], [-8, -3, -1, -1, 1, 1, -1, -1, -2, -5, 0], [3, -2, 2, -2, -1, -3, 2, -2, -1, -1, 0], [3, -2, -2, 1, 3, -2, 0, 1, 1, -2, 0], [-2, -3, 2, 0, -1, -2, 0, 1, 3, -2, 0], [-1, 2, -3, 3, 0, 1, 0, 2, 0, -2, 0], [-1, -3, -3, 3, 1, -1, -2, 1, 2, 3, 1], [7, -1, -2, 1, 0, 2, 0, -2, -4, -4, 2], [-4, -3, -4, 4, 4, 0, -1, 0, 4, -2, 2], [-16, 2, -2, 0, -2, -1, -2, 2, -1, 0, -1], [1, 2, -1, 1, -5, -2, 4, 0, 0, -3, 3], [13, 1, -1, 1, 3, 2, -1, -1, -1, 8, 0], [-3, 2, 4, 1, -2, -5, 1, -4, 2, -2, -4], [4, -2, 1, 1, -1, 2, 0, 0, 0, 3, 0], [-10, 4, 2, -2, -3, -2, 2, -5, -4, -5, 2], [0, 2, 1, -4, -2, 1, 2, 3, 2, 1, 0], [-2, -2, 0, 0, -3, 2, -3, 0, -2, 2, 4], [-14, -1, -3, 0, -3, -2, 1, -2, -1, -6, 2], [-4, -5, -1, -2, -3, -2, 1, -2, -3, -9, 2], [7, 1, 0, -2, 0, -3, 3, 1, 1, 7, -2], [-1, -1, -4, 1, 1, 0, 3, 1, 0, -4, 2], [-14, 2, -1, 6, 2, -1, -2, -1, 4, 3, 1], [11, -2, 3, -2, -1, 2, -1, 6, 5, 8, -3], [2, 1, 4, -4, 2, 1, 1, 4, 0, 3, -3], [9, 3, 6, 0, 0, 1, 0, 0, 3, 2, -4], [2, -2, -3, 4, 1, -2, -1, 1, 2, -3, -1], [14, 2, -2, 5, 0, 1, -3, 3, 4, 3, 1], [18, 4, 2, -4, -3, 3, 0, -1, -3, 1, -1], [2, 6, -3, 6, 3, 0, -2, -2, -3, 6, 2], [-13, 1, 1, 2, -5, 0, 1, -2, -4, -4, 2], [3, 3, 3, 3, 1, -1, 2, 0, 3, -3, -2], [-8, -2, 2, 0, 1, 3, -4, 1, 2, 5, -2], [16, 0, -3, 2, 0, 1, -3, 4, 2, 3, -3], [2, 0, -1, 0, 3, 3, -4, 3, -2, 3, -1], [-2, 3, 2, -3, -3, 0, -2, 0, 3, 3, -2], [-8, 1, -3, 2, -2, 1, -1, -4, -2, -8, 0], [8, 1, 3, -1, -4, -2, 3, 1, 4, 4, 0], [-12, 2, 2, 0, -2, 2, 2, 0, -1, -2, -1], [0, -7, -2, 1, 0, 3, 0, 0, 1, -1, 1], [2, 2, 4, -3, -2, 2, 0, 3, 0, 2, -3], [-9, 1, -4, 2, 6, 3, -1, 1, -2, 5, 1], [-6, -3, -2, 3, 3, 0, -3, 0, 1, -5, -1], [8, -3, -3, -1, 1, 0, -2, 1, -1, 0, -2], [-4, 1, -2, -1, 0, 1, 2, 1, -1, 7, 3], [11, -7, -1, -2, 2, -2, -3, 1, 2, -3, -2], [1, -4, -1, 6, 1, -1, 4, -2, 0, -2, 4], [-13, 4, 1, -1, 3, -3, 3, 1, -1, 0, 1], [8, 6, 2, -1, 0, 3, -2, 2, -2, 7, 3], [9, 3, 0, -2, -2, 0, 5, 0, -2, 7, 2], [9, 3, -1, -5, -5, 2, 2, 2, -1, 0, 1], [-5, 2, -1, 0, 2, -2, 3, -3, -1, -2, 1], [-11, 2, 5, 1, 2, 1, 3, 0, 4, 1, -2], [-5, -1, 4, 2, -3, -1, -1, -2, 0, -2, 1], [1, 7, 0, 4, -3, -5, 1, -2, -1, 0, 5], [1, 5, -1, 4, 1, 3, -3, -2, -2, 1, -2], [-1, -2, 0, 0, 0, -1, 4, -1, 1, -2, 5], [-9, 7, -1, 3, 1, 2, 3, -1, -3, 0, 0], [6, -3, 4, -3, 2, 2, -3, 2, 2, 4, -8], [-15, 8, 0, 1, -1, 4, -5, 3, 0, 5, -1], [9, -6, -1, -1, -2, -1, 1, -1, -6, 0, -1], [-10, 5, 0, 2, 0, -1, 1, -1, 1, 0, -4], [-7, 1, 4, 1, -5, -4, -2, -4, -3, 0, -1], [-1, 2, -3, 2, -3, 2, 5, 1, 0, -2, 3], [1, -5, 0, -5, -4, 0, -1, 5, 0, 2, 0], [1, 1, 0, -1, 2, 4, -2, 1, 0, 4, -1], [5, 0, 0, 2, -2, 3, -6, -1, -1, 2, -1], [-1, 0, 2, -6, 0, -1, 2, -1, -3, -8, 3], [-5, -4, -1, 1, -4, -1, 3, 0, -2, -3, 2], [-6, -5, 2, -2, 1, -3, -1, -4, 3, -2, 1], [13, -4, 4, -7, 2, -1, 0, 2, 2, 10, -1], [4, 1, -1, -3, -3, 0, 3, 4, -1, -1, 0], [0, 4, 0, 1, -2, -5, 4, 0, 1, -3, 6], [0, -5, -4, 4, 7, -3, 1, -1, 4, 2, 0], [-1, 8, 0, 1, 0, 0, 6, -2, -3, 0, 3], [5, 1, 0, 4, -1, 1, 1, -3, -4, -7, 1], [7, -10, 0, 2, 3, 1, -1, 4, 5, -1, -4], [2, -9, -3, -3, -4, -3, 2, 1, 2, 4, 1], [-9, -5, -5, 5, 3, 1, 2, 3, 0, 4, 4], [2, -4, -2, 0, 1, 3, 2, 1, 0, 4, 4], [1, -3, 0, 0, 1, -3, -1, 0, 4, -6, 0], [-12, 8, -3, 5, -3, 0, 2, 0, -2, 3, 4], [-1, 4, 0, 3, 1, 3, -3, 2, -1, -1, -1], [-5, 2, 2, 2, 2, -1, -3, 1, 4, 5, 0], [5, -2, -1, 0, 3, -4, 2, -1, 1, 6, -2], [8, 0, 1, 0, 1, 1, -6, -1, 1, 4, -4], [-3, 7, 0, -1, 7, -1, 0, 0, 0, 6, -1], [-6, -3, 1, -4, 2, -4, 1, -1, -1, 3, -3], [-4, 0, -2, 4, 5, -5, 1, -3, -2, 2, 3], [1, 8, 1, -1, -5, -5, 2, 2, 4, 5, 0], [10, 5, 0, -6, -3, 2, 1, 6, 1, 3, 0], [-4, 2, -4, 4, -4, -2, 0, 0, -2, -2, 2], [17, -5, -2, -3, -3, 4, -5, 1, -5, -5, 2], [-8, 2, 1, -1, 2, 1, 2, -2, -4, -2, -4], [-20, 4, -8, 6, 0, -2, 1, -3, -1, -4, 4], [-8, -2, 1, -6, -4, -1, 3, -5, -3, -12, -1], [3, 2, 6, 2, -2, -5, 0, -3, 3, -2, -1], [24, 0, 4, -2, -4, -1, 0, 0, -1, -4, -4], [2, -2, -1, 3, 2, 0, -2, 2, 0, 7, 2], [4, -5, 2, -4, -3, 3, -2, 1, -1, -1, -2], [-1, -2, 6, 0, -3, 0, -3, -1, 1, 0, -4], [11, 2, -3, 2, 1, 6, 0, 1, -4, 0, 0], [-28, -1, -2, 1, -5, 2, 1, 1, -1, -1, -1], [-7, -2, -1, -3, 0, 0, 0, 0, 0, 4, 2], [-8, 2, 0, 4, -4, -3, -3, 0, 3, 4, 0], [12, -6, 4, -2, -5, 0, -2, 1, -2, -3, 1], [-11, 1, -1, 6, 3, -2, -2, -2, 3, 3, 0], [-14, 12, -1, 3, 7, 1, -1, -1, -1, 3, 0], [6, 8, 3, 1, -3, -2, -1, 2, 3, 2, -6], [-11, -2, 4, 0, 1, 2, -2, -3, 1, 0, 0], [-24, -9, 0, -4, -2, 1, 3, -1, 1, -9, -2], [-12, 6, -2, 8, -4, -4, 2, -5, -5, -5, 6], [-20, 0, 0, -8, 0, -1, 5, -1, 3, -1, 0], [-9, -8, 5, -9, 2, 0, 3, 6, 3, -1, -5], [-7, 1, -2, -1, 3, -7, 2, -6, 0, -8, -2], [-4, -2, 3, -5, 5, 3, -4, 4, 0, 4, -1], [11, 6, 2, 1, 0, 3, -4, 1, 3, 9, -5], [-2, 7, 3, 6, -1, 0, 1, -2, -1, -1, 2], [-9, -7, -1, -1, -6, 0, 0, -4, -7, -9, 5], [24, 2, 0, 5, -2, 1, -1, -3, 1, 5, -1], [-9, -3, -3, 1, -2, -7, 3, 0, 2, -3, 1], [10, 1, 4, -3, -4, 3, -1, 1, -4, 4, -2], [-7, 1, 1, -6, 0, 2, 4, 0, 4, -2, -2], [-4, -3, 2, 1, -5, 2, 1, 2, -1, 4, 1], [10, -8, 5, -6, 2, -4, 1, -4, 3, 0, -2], [-6, 0, 3, 1, -2, 2, -4, 1, 1, -2, -7], [6, 0, -1, -1, -4, 0, 0, 0, -4, -6, 5], [24, 0, 2, -4, -7, 0, 2, 0, -2, -2, -1], [5, 5, -2, 7, 3, 4, -4, 3, 3, 7, -1], [18, 2, -4, 2, 2, -4, 2, -1, -3, -8, 4], [-5, -6, -3, -1, 1, -1, -3, 3, 0, -2, -2], [-9, 0, 4, -8, 1, -1, 1, 3, 2, 13, -1], [-6, 2, -2, 3, 1, -8, 7, -6, 4, -5, 4], [13, 5, -3, 2, 2, -4, 0, 0, -3, 3, 2], [-5, 4, 1, 2, 2, 6, 0, 6, 1, 1, -3], [2, 2, -2, -4, 2, 0, 2, 6, 0, 2, 2], [-6, -3, -5, 1, 5, -5, 4, 0, 1, -5, 3], [10, -6, -1, -2, 6, -1, 2, 3, 6, 1, -4], [-14, -3, 0, 1, -2, -1, -3, 1, 4, 7, -4], [-4, 3, 7, -2, 5, 4, -2, 0, 4, 8, -5], [8, -11, 4, -2, 0, -2, 4, 0, 1, -1, 1], [-1, -3, 1, 2, -4, 2, -4, 3, 4, 2, 1], [-12, 5, -3, -5, 0, -4, 7, 1, -1, -1, 3], [13, -5, 3, 0, -2, -1, -3, 1, 1, -1, -5], [18, -3, 2, -2, -2, 3, -4, 0, -5, 4, -3], [-24, -3, -1, 3, 0, 1, -1, -2, -4, -7, 2], [2, -3, 7, -2, 1, -1, 0, 0, 3, -4, -2], [-1, 1, -3, 4, -2, 3, -4, -4, -6, -1, 0], [-1, -2, 1, -3, 4, 0, 3, -2, -5, -3, 2], [17, -7, -2, -3, 6, -1, 1, -1, 3, 2, -1], [-12, -4, 3, 3, -2, 0, 2, -4, -2, 1, 0], [11, -2, -1, 4, 4, -2, 2, -4, 1, -2, 3], [-22, -1, -4, -3, 0, 4, -1, 4, -1, 4, 3], [-3, -3, -1, 4, -2, -1, 3, 1, 2, -12, 3], [12, -1, -3, -3, 2, -6, 2, 1, 5, 2, -3], [-2, -4, 2, 1, -5, -3, 2, -1, 7, 2, 1], [0, -2, -4, 1, 2, 0, 0, -2, -2, 0, 2], [15, -4, -3, 3, 6, -2, -3, 0, 0, 4, 3], [-12, 5, -1, -2, -3, 1, -2, 3, -2, 9, -3], [15, 6, 0, 7, -3, 0, -2, -3, 0, -4, 3], [-5, 0, 1, 2, 3, -4, -1, 2, 5, 8, -1], [11, -1, -4, 0, -5, -3, -3, 2, -1, -3, 5], [-12, -1, 4, -2, -3, 5, -1, 5, 0, 0, -6], [8, 4, 2, -3, 0, 5, -5, 5, -1, 9, 0], [-24, 8, -2, -3, -1, -4, 4, -1, 1, -7, 1], [-13, 1, 2, -4, 1, -3, 0, -2, 3, -2, 0], [13, 1, -3, 5, -5, -3, 3, -1, -4, -4, 6], [9, 3, -1, 8, 4, -2, 1, 0, 3, 3, -1], [-10, 2, 5, -1, 2, 3, -6, 1, 5, 2, -3], [-1, 11, 2, -1, -2, 4, -1, 1, 3, 6, -5], [10, -5, 5, -5, 3, -1, 0, 5, 2, 6, -3], [-7, 4, -1, 1, 9, 2, -3, 4, 7, 11, -4], [12, 4, 4, 1, -10, -5, 3, 1, 0, 0, 2], [13, -8, -1, -2, -2, 0, -3, -1, 0, -7, -2], [-3, 8, 2, 1, -1, 1, 5, 2, 4, -7, 0], [-22, 7, 3, 1, 3, 3, -1, -4, 0, 2, -3], [12, 0, -2, 5, -5, 0, 0, -3, 4, -1, 0], [0, -1, 4, 1, -1, 5, -3, 7, 3, 6, -1], [-17, -5, 0, -2, 5, -1, 2, 4, 0, 2, -1], [-2, -10, 1, -7, 3, -1, -3, -1, 0, -3, 0], [20, -8, 2, -1, -1, -1, 0, 0, 0, -7, 2], [4, -9, 1, 3, -5, -4, -2, -4, -4, -13, 5], [13, -9, 0, -4, -8, 3, 0, 1, -6, -10, 0], [-15, 8, 3, -4, -2, 1, 0, 0, -3, 8, -3], [12, 2, 3, 4, -3, -3, 1, -2, 4, -5, 0], [-5, -4, -1, 0, 1, -6, -3, -4, -3, 2, -3], [-3, 10, -6, 8, 5, 3, -5, -7, -6, -5, 1], [14, -1, 0, 6, -3, 3, -4, 4, 3, 0, 3], [25, 6, 4, -2, 9, 6, -2, 5, 4, 16, -6], [1, 3, 0, 2, -9, 1, 4, -4, -7, -9, 7], [-16, 11, -2, 5, -1, 2, -3, -2, -4, 3, 3], [7, -5, -2, -1, 3, -4, 1, -5, -6, -10, 0], [-8, -5, 6, -4, 5, 3, -7, -1, 1, 7, -5], [-14, -9, -1, 1, 10, 0, -3, -3, 0, -7, 1], [-15, -2, 4, -2, 4, -3, 6, -1, 4, 2, -2], [10, 9, 1, -1, -3, 1, 1, 3, 6, -3, -4], [-6, 6, 1, 4, 2, -6, 1, -6, 4, -3, -1], [3, -5, 5, -10, 1, 0, 3, 7, 3, 5, -2], [10, 5, -2, 6, -3, -3, 6, 0, 0, 3, 5], [-16, 1, 1, -6, 3, 2, -2, 3, -3, 3, -4], [4, -7, 1, -8, -5, -1, 0, 2, -6, -12, 3], [-3, -3, 3, -2, -3, 3, 1, -1, 4, -4, 2], [11, -10, 5, -10, 2, -2, 3, 3, 6, 1, -4], [19, -5, 1, -2, 5, -5, -2, 2, 6, 5, -6], [-28, 1, 0, -2, 6, 2, -2, -2, 1, 4, -5], [41, -13, -1, -4, -6, 3, -6, 3, 0, -1, -4], [-17, 5, 8, -5, -4, 7, 2, -2, -4, 7, 1], [16, 1, -3, -3, 4, -8, 6, -2, -2, -3, 2], [-1, 11, -4, 3, 6, 2, -2, 1, -6, 0, -1], [6, 7, -1, 9, 2, 1, -2, 2, 4, 7, -2], [-2, -3, 0, -3, 1, -3, 9, 4, 2, 6, 1], [-32, 5, -3, 4, 1, -3, 4, -4, -4, -7, 2], [-6, 2, -1, 9, 0, -1, -3, -6, 0, 4, 0], [-11, 2, -1, 2, -5, 0, -5, 1, -1, -4, -3], [18, -3, -3, 6, -6, 3, -1, -1, 3, 2, 0], [-8, 6, -3, 4, 2, -3, 8, 2, -2, 0, 3], [11, 5, -4, 6, 0, 0, -2, 3, 5, 4, -4], [3, 1, 4, -7, -4, 2, -1, 3, 1, 1, -4], [22, -2, -1, 1, -5, 0, 2, -5, -1, -3, 3], [10, -1, -5, 6, 1, 0, 4, 2, -7, -8, 3], [-1, -1, 4, -3, -3, -2, 5, 1, -1, -3, 0], [8, -7, 6, 1, -1, 1, -3, -2, 1, 4, -2], [-3, -2, -3, 5, 0, 3, -3, -5, -6, -2, -2], [-7, 5, 0, 10, -1, 2, 1, -2, 1, 8, 1], [27, 0, 0, -1, 6, 2, -1, 4, 8, 5, 2], [15, -9, 6, -3, 1, 4, -5, 7, 4, 8, -8], [2, -2, -4, 0, 7, -2, 5, -3, -3, -6, 6], [23, -5, 3, 3, -5, 3, -3, 0, 4, 1, 1], [12, 10, -1, 1, -5, -5, 6, -1, 1, 4, 0], [-22, 3, -4, 7, -6, -6, 2, -5, -3, -9, 4], [-48, 2, 4, -3, -1, -10, 5, -6, 2, -4, 0], [22, -2, 3, -3, 4, -1, -3, -3, 0, -3, 0], [1, 7, 1, 3, 2, 1, 1, 5, 2, 8, 4], [11, 6, 1, 2, -2, 1, 3, -1, 6, 6, 1], [11, -7, -4, 3, 2, -10, -1, -4, -4, -13, 4], [-13, -6, -2, -4, 4, -6, 4, -3, 0, 0, -2], [4, -7, -3, 0, 8, 0, -2, 1, 5, -3, 2], [0, -6, 4, -10, 5, -1, 2, -2, -2, 2, -7], [15, 0, 1, 1, -6, -1, 3, -3, 5, -6, -2], [7, 9, -1, 1, -1, -7, 2, -3, -1, 5, 0], [-16, -5, -3, -2, -8, -2, 2, -4, -4, -4, 6], [-2, -2, 1, 0, -1, -4, -5, -4, 2, -5, -4], [15, 7, 0, -4, -1, 3, 0, 3, 5, -2, -4], [-1, -2, 2, -5, 8, -4, 5, 2, 0, -3, 5], [0, 6, 0, 4, 0, -3, 4, 2, 7, 0, 6], [-7, -5, 6, -4, 3, 3, -2, 2, 4, -1, -10], [-18, 6, 3, -8, 1, -8, 5, 5, 0, -4, -4], [-11, -1, 4, 2, 0, 3, -3, 5, -1, 2, 3], [10, -8, 2, -13, -6, 4, 3, 3, -3, -1, -1], [-10, 1, -3, -4, 3, 3, 1, 0, -8, -1, 0], [-13, 2, 2, 2, -3, 1, 0, 1, -1, 0, 1], [16, 1, 2, -7, -9, 1, 5, -1, -6, -12, 2], [7, 8, 3, -4, -2, 4, 4, 6, 3, 1, -6], [-1, 6, 4, -6, 0, 2, 7, 3, -5, -8, 2], [5, -4, 2, -3, -5, 10, -4, 4, 1, 8, -3], [-5, 2, 5, 6, 7, -4, 3, -8, 4, -1, -1], [-35, 2, -1, 3, -7, 1, -3, -4, -4, -3, 0], [-14, 0, -3, 6, 1, 1, 5, 1, 1, -10, 5], [-13, 6, -1, -4, 2, -6, -1, -1, -1, 5, -5], [-1, 0, 1, 4, 5, -2, 9, 1, 7, -2, 2], [6, -2, -2, 1, -1, -3, -1, -4, 1, -2, 5], [-22, 3, -5, 11, 4, 0, -3, -5, 1, 3, 5], [12, -5, 3, 4, 5, 5, -2, -1, -1, 7, 0], [7, 3, 1, 2, 2, -4, -1, 0, -4, -6, -2], [31, -1, 1, 0, -6, 3, -4, -2, -4, 1, -1], [-26, -2, -1, 4, -4, -7, -1, -8, 3, -11, -1], [20, -1, 2, -5, -2, -4, 1, 2, 3, 0, -10], [19, -8, 2, -2, -3, 11, -6, 2, -1, 5, 2], [15, 7, -6, 5, 5, 0, 1, -5, -5, -1, 1], [10, 0, -1, -5, 7, -2, 3, -4, -3, -8, 4], [16, 0, -4, 2, 4, -4, 12, -3, 1, -8, 2], [1, 5, 0, -7, -7, 2, 4, 0, 0, -4, -4], [-12, 6, 3, -5, -4, -2, 1, -5, -4, 2, -2], [17, -5, 7, -2, -8, -6, 5, -6, -1, -16, 2], [-9, -1, 0, 7, -3, -8, -4, -3, 1, -13, 3], [-14, 0, -2, -6, 2, -6, 5, -2, 2, -13, -1], [5, 6, 0, -6, -9, 5, -3, -3, -4, 1, 1], [-21, -5, 3, -6, 4, 1, 0, -4, -2, -7, 0], [-30, 7, -4, 9, 5, -1, 3, -3, 4, -4, 5], [0, 5, 1, 3, 3, -7, 10, -1, 1, -6, 6], [5, 13, 3, -11, -1, 1, -3, 3, -4, 9, -3], [17, 4, 0, 9, 0, 1, -4, -1, -3, 2, 3], [-5, 3, 7, -5, -2, 3, 1, -2, -1, 8, 1], [30, -10, -1, -3, -4, 7, -3, 7, 1, -10, -5], [27, -7, 4, -5, 3, 7, -3, 6, -1, 13, -4], [-13, -1, -2, 5, 9, -8, 3, -8, 4, -5, 5], [20, -6, -7, 11, 5, 2, -1, -5, -6, -3, 4], [8, 4, -3, -3, -1, 0, 3, 3, 1, 9, -3], [-17, 6, -2, -3, -2, -2, 1, -5, 2, 0, -3], [-6, 2, -2, 1, 0, -12, 3, -1, 7, -9, 0], [12, -6, 0, -2, 1, 6, -6, 3, 0, 11, -13], [23, -4, 4, -1, -1, -1, -1, 2, -2, 1, 0], [-14, -9, -4, -1, -5, -6, -1, -5, -2, -13, 3], [17, 5, -4, 5, -6, 1, 0, -4, -3, -1, 4], [-20, 6, 2, -4, -4, -4, -2, 3, -2, -2, -3], [1, 14, -3, 2, 2, 2, -1, -4, -6, 6, 6], [16, -3, -3, 2, 3, 7, -4, 8, -1, 3, -5], [11, 8, -3, 2, -7, 1, 1, -6, -8, -3, 5], [5, 2, -2, 3, -3, -2, -2, -2, -3, 6, 3], [25, -5, -6, 4, -8, -1, -2, 3, -1, -2, 3], [-7, -7, 2, -6, -1, -3, 1, 2, 3, -3, 4], [27, 6, 4, -6, -14, 0, -1, -1, -7, -7, 4], [5, 8, 0, 0, 3, -4, 0, 2, 4, -3, -8], [16, -1, 1, 1, -12, 2, -5, -2, 2, -4, -5], [-6, 12, -1, 3, 6, -7, 5, 0, 3, 5, 1], [11, -4, -5, 13, 3, -1, 0, -2, 3, -5, 1], [1, -1, 6, 1, -6, -4, 3, -1, 3, 5, -2], [-24, 10, 4, 6, 3, -9, 3, -4, 6, -4, -2], [-4, 3, 1, 2, 3, 3, -4, 2, 3, 2, -7], [-8, 18, 2, 7, 2, -2, 1, -4, 3, 2, -1], [18, -5, -1, 3, -1, 2, 3, -3, -5, -7, 5], [-17, -8, -3, 0, 2, -2, 0, 1, 0, -7, 3], [-15, 4, 1, 4, 2, -2, 3, -4, -1, 0, 3], [-8, -2, 2, 0, -1, -8, -1, -4, -3, -14, -3], [-7, 4, 7, -6, -3, 6, 3, 3, -1, -1, -4], [20, -7, 7, -8, 3, -3, 5, 1, -1, 6, 0], [1, 1, -6, 6, -3, 5, -6, -6, -3, -6, 6], [14, -1, -2, -12, -2, 1, 1, 5, -7, -1, -1], [18, -8, 2, 0, -3, 6, 0, 3, -4, 3, 4], [10, -12, -3, 0, 0, -3, -3, 1, -2, -7, 6]]
